##  Next Steps
SAP LeanIX has collaborative features to make user participation easier in enriching and validating data. As a next step, familiarize yourself with the following features that support collaboration with your organization's enterprise architects.
  * Comments: The Comments tab is available on all Fact Sheets. When a comment is posted on a Fact Sheet, the responsible persons for that Fact Sheet are promptly notified. This allows you to propose updates or seek clarification without directly altering the content of the Fact Sheet. This feature is beneficial, as it allows one to request support directly from the responsible person, avoiding the inconvenience of email and preventing them from being overwhelmed with excessive communication.
  * Survey: A Survey is a collaborative way to gather information from several stakeholders in one go. When the administrator, in this case, the Enterprise Architect, sends out surveys, the responsible contributors receive notifications in the Survey tab of the Fact Sheets as well as via email. The provided response could directly update relevant fields in the Fact Sheets. To learn more about Surveys, see [Surveys](https://help.sap.com/docs/leanix/ea/surveys?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX surveys streamline data collection and collaboration with seamless integration with fact sheets.").
  * Quality Seal: The Quality seal is a mark of accurate and up-to-date data on a Fact Sheet. A responsible or accountable subscriber of the Fact Sheet approves the Quality Seal after verifying correctness and completeness. If any user who is not responsible or accountable makes a change to the Fact Sheet, the Quality Seal is broken. The responsible or accountable subscriber can easily notice this change through the Quality Seal indicator button located at the top right of every Fact Sheet. To learn more about Quality Seal, see [Quality Seal](https://help.sap.com/docs/leanix/ea/quality-seal?locale=en-US&state=PRODUCTION&version=CLOUD "Quality seal ensures data integrity by assigning approval responsibility to accountable and responsible subscribers of fact sheets. When broken, it prompts verification and approval of fact sheet information.").


![Collaboration features in Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749afcb7a4410148828ab4dd9cc8e6b_LowRes.png)
Collaboration features in Fact Sheet
YesNo
Send
